@@ -51,6 +51,7 @@ EXTENSIONS = {
     'eot': {'binary', 'eot'},
     'eps': {'binary', 'eps'},
     'erb': {'text', 'erb'},
+    'erl': {'text', 'erlang'},
     'exe': {'binary'},
     'eyaml': {'text', 'yaml'},
     'f03': {'text', 'fortran'},
@@ -79,6 +80,7 @@ EXTENSIONS = {
     'hcl': {'text', 'hcl'},
     'hh': {'text', 'header', 'c++'},
     'hpp': {'text', 'header', 'c++'},
+    'hrl': {'text', 'erlang'},
     'hs': {'text', 'haskell'},
     'htm': {'text', 'html'},
     'html': {'text', 'html'},
@@ -333,7 +335,10 @@ NAMES = {
     'pylintrc': EXTENSIONS['ini'] | {'pylintrc'},
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
+    'rebar.config': EXTENSIONS['erl'],
     'setup.cfg': EXTENSIONS['ini'],
+    'sys.config': EXTENSIONS['erl'],
+    'sys.config.src': EXTENSIONS['erl'],
     'WORKSPACE': EXTENSIONS['bzl'],
     'wscript': EXTENSIONS['py'],
 }
